@@ -3,14 +3,23 @@ from abc import abstractmethod, ABC
 from ase import Atoms
 import numpy as np
 from clease.montecarlo.constraints import MCConstraint
-from clease.tools import SystemChange
+from clease.datastructures import SystemChange
 from clease.montecarlo.swap_move_index_tracker import SwapMoveIndexTracker
 
-__all__ = ('TrialMoveGenerator', 'RandomFlip', 'RandomSwap', 'MixedSwapFlip')
+__all__ = ('TrialMoveGenerator', 'RandomFlip', 'RandomSwap', 'MixedSwapFlip', 'TooFewElementsError')
 
 DEFAULT_MAX_ATTEMPTS = 10000
 
 
+class TooFewElementsError(Exception):
+    """
+    Error that indicates that there are too few elements to perform a certain operation on
+    an atoms object. An example is a Monte Carlo step at fixed concentrations which consists
+    of swapping to atoms. If there are less than 2 different species in the Atoms object, it
+    makes no sense to swap two atoms (all energies are equal)
+    """
+
+
 class TrialMoveGenerator(ABC):
     """
     Class for producing trial moves.
@@ -169,6 +178,10 @@ class RandomSwap(SingleTrialMoveGenerator):
         if self.indices:
             self.tracker.filter_indices(self.indices)
 
+        if self.tracker.num_symbols < 2:
+            raise TooFewElementsError("After filtering there are less than two symbol type left. "
+                                      "Must have at least two.")
+
     def get_single_trial_move(self) -> List[SystemChange]:
         """
         Create a swap move
