@@ -5,7 +5,7 @@ import logging
 from pathlib import Path
 from itertools import (permutations, combinations, product, filterfalse, chain)
 from collections.abc import Iterable
-from typing import List, Optional, Tuple, Dict, Set, Sequence, NamedTuple, Union
+from typing import List, Optional, Tuple, Dict, Set, Sequence, Union
 from typing import Iterable as tIterable
 from typing_extensions import Protocol
 import numpy as np
@@ -238,9 +238,9 @@ def get_all_internal_distances(atoms, max_dist, ref_indices):
     return np.array(distances[1:])
 
 
-def reconfigure(settings, select_cond=None):
+def reconfigure(settings, **kwargs):
     from clease.corr_func import CorrFunction  # pylint: disable=import-outside-toplevel
-    CorrFunction(settings).reconfigure_db_entries(select_cond)
+    CorrFunction(settings).reconfigure_db_entries(**kwargs)
 
 
 def split_dataset(X: np.ndarray,
@@ -1069,10 +1069,3 @@ def get_cubicness(atoms: ase.Atoms) -> float:
     # Take absolute value, as determinants can be negative.
     # We just need it to be as close to 0 as possible
     return abs(np.linalg.det(cell - diag))
-
-
-class SystemChange(NamedTuple):
-    index: int
-    old_symb: str
-    new_symb: str
-    name: str
